Negative Sampling
=================
.. automodapi:: pykeen.sampling
    :no-heading:
    :headings: --
    :skip: NegativeSampler

Base Classes
------------
.. autoclass::  pykeen.sampling.NegativeSampler
    :members:
    :exclude-members: get_normalized_name, num_entities
